/*
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 */ 
package org.apache.rat.analysis.license;

import org.apache.rat.DeprecationReporter;
import org.apache.rat.license.ILicenseFamily;

@Deprecated // remove in v1.0
@DeprecationReporter.Info(since = "0.16", forRemoval = true, use = "new configuration options")
public abstract class BaseLicense implements DeprecatedConfig {
    private String licenseFamilyCategory;
    private String licenseFamilyName;
    private String notes;

    public BaseLicense() {
        DeprecationReporter.logDeprecated(BaseLicense.class);
    }

    public String getLicenseFamilyCategory() {
        return licenseFamilyCategory;
    }

    public void setLicenseFamilyCategory(String pDocumentCategory) {
        licenseFamilyCategory = pDocumentCategory;
    }

    public String getLicenseFamilyName() {
        return licenseFamilyName;
    }

    public void setLicenseFamilyName(String pLicenseFamilyCategory) {
        licenseFamilyName = pLicenseFamilyCategory;
    }

    public String getNotes() {
        return notes;
    }

    public void setNotes(String pNotes) {
        notes = pNotes;
    }
    
    @Override
    public final ILicenseFamily getLicenseFamily() {
        return ILicenseFamily.builder()
        .setLicenseFamilyCategory(licenseFamilyCategory)
        .setLicenseFamilyName(licenseFamilyName)
        .build();
    }
}
